MultiFrames

Struct MultiFrames 

pub struct MultiFrames<'enc, 'prl, 'mm, U>(/* private fields */)
where
    'prl: 'enc,
    'mm: 'enc;
A wrapper type for encoding multiple frames

Implementations

Source

impl<U: PixelType> MultiFrames<'_, '_, '_, U>

pub fn add_frame<T: PixelType>( self, frame: &EncoderFrame<'_, T>, ) -> Result<Self, EncodeError>

Add a frame to the encoder

Errors

Return EncodeError if the internal encoder fails to add a frame

pub fn add_jpeg_frame(self, data: &[u8]) -> Result<Self, EncodeError>

Add a JPEG raw frame to the encoder

Errors

Return EncodeError if the internal encoder fails to add a jpeg frame

pub fn encode(self) -> Result<EncoderResult<U>, EncodeError>

Encode a JPEG XL image from the frames

Errors

Return EncodeError if the internal encoder fails to encode